GlycinFrameExt

Trait GlycinFrameExt 

pub(crate) trait GlycinFrameExt {
    // Required methods
    fn has_delay(&self) -> bool;
    fn delay_duration(&self) -> Option<Duration>;
    fn texture(&self) -> Texture;
}
Extensions to [glycin::Frame].

Required Methods

fn has_delay(&self) -> bool

Whether the frame has a delay, which means that the image is animated.

fn delay_duration(&self) -> Option<Duration>

How long to show this frame for if the image is animated, as a Duration.

fn texture(&self) -> Texture

Convert this frame to a gdk::Texture.

Implementations on Foreign Types

Source

impl GlycinFrameExt for Frame

Implementors