pub(crate) trait GlycinFrameExt {
// Required methods
fn has_delay(&self) -> bool;
fn delay_duration(&self) -> Option<Duration>;
fn texture(&self) -> Texture;
}Expand description
Extensions to [glycin::Frame].
Required Methods
Sourcefn has_delay(&self) -> bool
fn has_delay(&self) -> bool
Whether the frame has a delay, which means that the image is animated.
Sourcefn delay_duration(&self) -> Option<Duration>
fn delay_duration(&self) -> Option<Duration>
How long to show this frame for if the image is animated, as a
Duration.
Sourcefn texture(&self) -> Texture
fn texture(&self) -> Texture
Convert this frame to a gdk::Texture.